---
title: "Justice Culture and the Enlightenment"
date: 2019-11-25T12:03:26Z
tags: []
topics: []
image: img/blind-lady-justice.jpg
draft: false
---

A question is posed to me via my coursework: “*Does justice require that anything be distributed equally? If so, what?*” This is, of course, the bog-standard prompt for the student to explain the modern dispute between John Rawls[^1] and Robert Nozick[^2] . We’ll get there shortly, but first I want to back up and ask the more fundamental (indeed, perennial) question: *What is justice?* At the risk of plagiarizing Socrates, I might clarify that I am not asking, “*what makes a just circumstance just*“, or “*show me a particular instance of a just set of arrangements*“. Rather, I want to know about *Justice qua Justice*. In more common terms, can we adequately describe the thing at which we point, when we want to say “this thing is like that thing”. Once we can answer that question, then we can begin to consider the question of what prerequisites must be met in any given circumstance, in order to declare, “this is a just arrangement of goods”. Of course, I’m not going to be able to answer that question in this post. But what I can offer, are some thoughts and observations on the concept, that give the coursework question some context, and some real-world purchase.

Some say that justice obtains in an ordering of goods such that certain moral principles are adequately respected. The meting out of rewards and punishments according to a proportional measure, or the distribution of wealth according to a preference for moderation and an avoidance of excess, for example. All of these theories, whether egalitarian, aristocratic, libertarian, or meritocratic, have a tension at their core: the autonomy of the individual as against the prerogative of the society within which he exists. The recognition of that tension goes straight back to Plato[^3]. Its source is a fundamental insight of his: the role of the individual in society, the relationship he has with his society, and the kinds and degrees of liberty, equality, obligation, and right he has, is a direct consequence of the unifying value around which the society is formed, matures, and flourishes. That fundamental value becomes the primary good toward which the society strives, and it operates, at least, as the proxy standard for justice in that society.

In the deep past, the fundamental at the core of any healthy society (as the ancients saw it) was typically something like the material success of an ethnic family as a whole. The triumph of the Spartans over the Athenians was, for the Spartans, a testament to the superiority of their tribe. The conquest of the Barbarians by the Romans, was a testament for the Romans, of the superiority of Roman martial virtues. In both of these examples, the sacred is the tribe and its cultural expressions. The superiority of these concepts is directly related to the successes earned in the real world, against foes.

All that changed, I think, with the rise of Christianity. No longer is some notion of solidarity to an ethno-cultural identity the ground of moral legitimacy, but a set of sacred ideals revolving around a faith-based belief. The Catholic church that rose out of the collapsing Roman empire valorized very Platonic notions of Truth, Goodness, and Beauty, and coupled them with liturgical concepts of Love, Sin and Redemption through the sacrifice of Christ[^4]. At which point, European and English societies had a transcendent focal-point that superseded their own tribal instincts, and gave them a common cause, whose integrity held until the Enlightenment. However, the Enlightenment did not abandon the valorization of abstract Platonic ideals as organizing principles for society over tribal identity. Rather, it attempted to replace the abstract ideals of “scholastic” medieval society, with new ideals. Ideals that were meant to diminish the authority of the church and state, and strengthen the individual. The goal was, in the spirit of the new scientific approach to the world, to find a single unifying principle of human nature[^5] that could unite all of humanity under a single umbrella of brotherhood. You can see the ecstatic expression of this goal in the poetry of Schiller[^6] and Goethe.

The United States would appear to be the final political expression of that transformation. But, if the goal was a single, unifying ideal, then the project is incomplete. American society seems to be grounded in not one, but two sacred values given to it by the Enlightenment: Liberty and Equality. These ideals on their own are not unique to the United States, but they are unique in their combination and expression in the United States. Even in the country that is their intellectual home, they are combined with yet a third ideal that, arguably, stands as the real primary — and it harkens back to the pre-medieval heritage of the nation. I am, of course, speaking of France, and its famous triumvirate of ideals: Liberty, Equality, and *Fraternity*. Fraternity, however, is not understood by the French as Schiller or Goethe would have meant it (as a universal brotherhood of all men). Rather, it is indeed a statement of ethno-cultural solidarity. It is the Frankish People, who love their pastoral homeland, whose sacred heart is Paris, and out of whose ranks rose such renowned names as Charlemagne, Louis IX, Rousseau, Robespierre, Napoleon, de Gaul, Sartre, and Foucault. This sort of tribal identification is the bit that is missing from the American political ethos. Even the Russians, with their nearly eighty year long dysfunctional love-hate relationship with Marxism, have been unable to shake their ethno-cultural tribal identity as a core political value over and above the Communist egalitarianism that nearly destroyed them.

The “American People”, such as they are, have always been a hodge-podge of ethnic and social confusions. At first, loosely affiliated colonial villages made up of Dutch, English, Spanish, and French settlers and explorers, all arrayed more or less against the indigenous populations. Because the English were the dominant presence in the colonies, it is their legal culture and political philosophy that dominate the institutions of those early settlements. For the English, an early form of individual sovereignty grounded in property rights derived mainly from colonial corporate charters and the heritage of the Magna Carta put Liberty front and center as the core value of that society[^7]. Their most successful political competitors were the French, and the colonial period also happens to be the most productive period for the French segment of the Enlightenment. For thinkers like Rousseau, the highest ideal was Equality (see his {{< newtab title="Discourses on Inequality," url="https://aub.edu.lb/fas/cvsp/Documents/DiscourseonInequality.pdf879500092.pdf" >}} for example). Thus, this too became a motivating force in early colonial life, and later alloyed to Liberty, the composed the dual pillars of the American polity. Yet, apart from their shared experience of extreme hardship on the frontier of a new continent, there was very little on offer in the way of a tribal identity known as “American”. Instead, the label was as sort of circumstantial short-hand. It’s true that de Tocqueville use the term “American” in a quasi-ethnic sense, but his use invoked an imaginative idea of the Puritans as a way to characterize the attitudes of all who populated the newly formed nation. In general the term “American” was just a convenient way of referring to the people who chose to live on the new continent, be they English, French, Dutch, Spanish, or eventually Irish, German, Italian, Russian, Chinese, Portuguese, or later still, Turkish, Greek, Polish, and Arab.

The implications of this are staggering. For the first time in human history, you have an entire continent that represents a veritable blank-slate upon which could be inscribed any and all of the human yearning to learn and grow and explore, and it just so happened to coincide with the explosion of Enlightenment idealism in the popular culture — the secular philosophical cousin of the ancient Catholic ideal of the “universal church”. It is this highly religious notion of Enlightenment universalism that envelopes and informs the American understanding of the ideals of Liberty and Equality. The words of Paul in Galatians must have been ringing in Jefferson’s ears, as he penned the first words of the Declaration of Independence: “*there is neither Jew nor Gentile, neither slave nor free… for you are all one in Christ Jesus…*” ({{< newtab title="Galatians 3:28" url="https://www.kingjamesbibleonline.org/Galatians-3-28/" >}}).

It is this universalism that acts as the “glue” binding Liberty and Equality together, and it is this universalism that some have tried to engineer into a new kind of limitless ethno-cultural identity, which could function as a final form of tribal identity: the tribe of the human race. But this is a mistake. Enlightenment universalism cannot replace tribal allegiance, and it cannot function as a higher-order value to which Liberty and Equality must pay homage. First, because it is limitless and tribes, by definition, are limited to specific very concrete characteristics. Second, because it lacks the particularity of its original religious parent. The “universal church” works, because it offers Christ up as a kind of ideal man, which functions as a model for emulation, and upon which can be focused our moral aspirations. Enlightenment universalism offers only the ecstatic sentiment of Schiller’s “spark of divinity” found in all men alike, but no guide as to what to do about that spark.

\* * * *

It is in this historical context that we arrive at our original question: “*does justice require that anything be distributed equally? If so, what?*“. Let’s bring the discourse back down to earth, and consider it in concrete terms. The modern theorist of “distributive justice” sees his role in much the same way an economist might, except as a moral accountant rather than a material one. All the goods that really matter are material goods (and ‘material’ includes such things as circumstantial goods like ‘opportunities’), and the task of the theorist is to devise a method for deciding how to apportion those goods amongst the living. In short who gets what, and why? These theorists all take a kind of comparative attitude as their starting point. Johnny has three apples. Janey has four apples. Is it a good thing or a bad thing for Janey to have one more apple than Johnny? At which point, they will all line up on one side or the other of the question, offering various rationales for each side: the effort required to obtain the apples, the adequacy of access to the apple trees, the race and gender of Johnny and Janey, their relative health and vigor, the effects of emotions like envy and jealousy, the scarcity of the apples, the fulfillment inherent in the work of apple picking, the circumstantial luck involved in the selection of trees to pick from, and on and on. There is an assumption lurking quietly under the moral question first raised. Namely, the default position against which all deviations require a moral justification is relative equality. Johnny and Janey *ought to have the same number of apples* unless you can provide a moral justification for it being otherwise.

The debate between the two most prominent theorists of distributive justice in the twentieth century can dramatically illustrate this assumption. John Rawls concocted a thought experiment designed to convince us all that if we were in an “original position” behind a “veil of ignorance”, we would all rationally choose to organize the democratic society in which we presently lived, in such a way that it minimized the personal risk of being trapped permanently at the bottom of the economic heap. This was indeed meant in a very economic sense (Rawls ruled out things like slavery and extreme scarcity, because he starts from a presumption of modern abundance). He further argued that the presence of any wealth or income inequalities would only be justified where it could be shown to be “for the benefit of all”. Robert Nozick famously retorted with a thought experiment of his own, involving Wilt Chamberlain and a special collection box into which his fans could divest themselves of any unused quarters, in his name. Nozick wasn’t arguing that he had an example of Rawls’ Difference Principle in action. Rather, Nozick takes Rawls’ claim that Liberty is primary seriously, but Rawls does not. Rawls’ defenders claim that Rawlsian Equality is a necessary precondition for true Liberty, arguing that, after all, it takes access to wealth to be able to make certain choices (e.g., going to school or starting a business). Defenders of Nozick retort that the forced appropriation of property in order to satisfy a requirement for a “patterned distribution” is a direct violation of Rawls own Liberty Principle, which Rawls claimed was lexical in his scheme.

To an extent, both men are correct. Contrary to some who claim that Liberty and Equality are consonant ideals, it does seem fairly clear that taken to their limits, these ideals are direct competitors (and at the present moment of history, it appears Equality may have gained the high ground against Liberty). What’s more, I am not convinced that a reconciliation is possible between them. The reason is because these ideals are *moral principles*, fundamentally. Any society that is organized around a moral principle (rather than, say, a primitive need, a tribal identity, or a secondary cause) is going to work to expand the scope of the principle as a means of perfecting the society relative to it. Liberty is one of those principles that, when extended to its limit, is incapable of admitting any other principle. It begins with the liberty to do what you must; extends to the liberty to do what you can, in the face of material obstacles; and finally ends with the liberty to do as you please, regardless of material or moral constraints. Likewise with Equality. At first, the concern is for procedural fairness, and impartiality, i.e. “equality before the law”; it extends to notions like “equality of opportunity” and “equality of regard” (which we can see overtaking the culture of the west now); and finally ends in absolute equality, in which the state spends all of its effort on capture and redistribution of all inequalities, regardless of material contingency or moral justification. It is at these extremes where we can see Rawls and Nozick intuitively anticipating the failure of each others’ doctrines.

The implications for the United States (and to some extent, the UK and Europe) are dire. As mentioned above, our political society is grounded on both of these ideals, and as I’ve shown here with at least these two ideals, no society can sustain itself, where competing ideals form its foundation. Eventually, factions will form around these ideals, and the inevitably irreconcilable conflict will fracture it. Already, we could see this conflict bubbling up in the 19th century. But I think it was averted by the Civil War. Just at the moment that Liberty and Equality were sure to drive the union itself into dissolution, Lincoln appeared and elevated a third principle above them. He made this explicit in his famous {{< newtab title="Gettysburg Address." url="https://www.britannica.com/event/Gettysburg-Address" >}} He says of the federal union, that it was “*conceived in Liberty, and dedicated to the proposition that all men are created equal*“. He understands the dual moral loyalties of the Founders. And, he realizes what is needed to reconcile the conflict. He shifts the language. He calls the United States a *nation*, and insists that we have a duty before God, and a sacred debt to the dead, to insure that it “never perishes from the earth”. Union, then, becomes the overarching principle, to which Liberty and Equality are subordinated. His “new birth of freedom” is a demotion for both equality and freedom. But subordination might be exactly what is needed.

Other than a concrete goal such as the self-preservation of an existing state (the preservation of the American union, for example), or an arbitrary notion like ethno-cultural identity (particular heritages such as the Frankish, Slavic, English, etc), or a religious commitment (i.e. a theocracy), it is not clear what could fill the role of ultimate purpose, to which all other ideals could be subordinated. I am well aware of the spectre I am raising in all this talk of ethno-cultural solidarity and theocracy. The tribal instinct in man is a powerful one, and a deadly one. I am clear-eyed about the very real threat it presents. At the same time, I am also aware that the sort of quirky experiment that the Enlightenment was, is an aberration in human history, that it is frightfully young and vulnerable, and that it makes extreme counter-evolutionary demands upon us that I suspect are unsustainable. Recent naive utopian attempts at achieving those counter-evolutionary dreams have largely been a horror show of their own.

Perhaps what is needed, is a fresh look back at the ancients, again. It could be, that a thoroughgoing re-evaluation of the Greeks, Romans, and early church fathers of the Catholic tradition, could yield insights we haven’t noticed before, in the light of modern scholarship, linguistic prowess, and technological advancements. Another possibility, is the fusion of Humean naturalism and the psychological sciences that sprang from it, with the intellectual and mystical traditions of early Christianity (Plato, Aristotle, Paul, Augustine, Aquinas, et. al.). Perhaps justice, in the end, is exactly as the Greeks imagined it: everything in its proper place, and aiming toward its proper end. Aristotle began the work of systematizing this in the Nicomachean Ethics, with his notion of justice as a balancing of terms in a ratio, rather than the modern idea of a leveled plane. Some claim that Aristotle’s concept was a purely legal one (which is why a blind woman holds aloft a balanced scale, in front of every American court room). But I think this is far too narrow an interpretation of his idea. For Aristotle, what is owed and what is deserved, are a numerator and the denominator that must reduce to 1, if justice is to be served. Likewise, across a society, all numerators and denominators must resolve ultimately to 1. In such a scheme, Liberty and Equality would resume their proper role as instrumental goods enjoyed in measures that balanced the scale. The very first thing Aristotle argues for in the Nicomachean Ethics, is an ideal of the greatest good for man. He calls this “Eudaemonia”, which as near as I can tell, means something like the pride of conscience experienced when surveying an entire life lived in excellence (according to the virtues). What we like to call “happiness”, today (also the term used by Jefferson). Justice, then, would be the balance of contributions made and rewards given, to a life lived in excellence in the polis. As long as the ratio of those two things reduces to 1, justice is sufficiently met.

There is not enough room to explore this possibility any further here. Suffice to say, it is a live option. But, I would add this much: it seems to me that this is the only way to escape the predicament we find ourselves in. Clearly, composites of Enlightenment ideals are not sufficient. and a return to primitive tribal principles are a non-starter. Liberty and Equality must be dethroned as ultimate ends. But what are they to serve as their new master? A return to primitive tribal concepts like ethno-cultural solidarity are a non-starter. So, a new philosophical understanding is needed. One that locates justice in some higher ideal than we’ve yet imagined. But what is that? I don’t know if there is an answer to this question.

```[Imported from exitingthecave.com on 29 November 2021]```



[^1]: [John Rawls’ Difference Principle](https://plato.stanford.edu/entries/justice-distributive/#Difference) [↩](https://exitingthecave.com/justice-culture-and-the-inheritance-of-the-enlightenment/#fnref-1)
[^2]: [Robert Nozick’s Patterned Distributions Critique](https://plato.stanford.edu/entries/nozick-political/#CriEndStaPatPri) [↩](https://exitingthecave.com/justice-culture-and-the-inheritance-of-the-enlightenment/#fnref-2)
[^3]: [e.g. Plato’s Republic](http://classics.mit.edu/Plato/republic.html) [↩](https://exitingthecave.com/justice-culture-and-the-inheritance-of-the-enlightenment/#fnref-3)
[^4]: [e.g. Augustine’s Doctrine of Justification](http://lonelypilgrim.com/2013/08/28/the-doctrine-of-justification-augustine-is-catholic/) [↩](https://exitingthecave.com/justice-culture-and-the-inheritance-of-the-enlightenment/#fnref-4)
[^5]: [e.g. Hume’s Treatise of Human Nature](https://www.gutenberg.org/ebooks/4705) [↩](https://exitingthecave.com/justice-culture-and-the-inheritance-of-the-enlightenment/#fnref-5)
[^6]: [The non-denominational deistic tendency of Schiller’s famous poem is typical of the ethos of the 18th century](https://penandthepad.com/meaning-poem-ode-joy-3627.html) [↩](https://exitingthecave.com/justice-culture-and-the-inheritance-of-the-enlightenment/#fnref-6)
[^7]: [See, for example, “The Rights of Englishmen”](https://en.wikipedia.org/wiki/Rights_of_Englishmen) [↩](https://exitingthecave.com/justice-culture-and-the-inheritance-of-the-enlightenment/#fnref-7)
